/* A Bison parser, made by GNU Bison 3.0.4.  */

/* Bison implementation for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* C LALR(1) parser skeleton written by Richard Stallman, by
   simplifying the original so-called "semantic" parser.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON 1

/* Bison version.  */
#define YYBISON_VERSION "3.0.4"

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 0

/* Push parsers.  */
#define YYPUSH 0

/* Pull parsers.  */
#define YYPULL 1




/* Copy the first part of user declarations.  */
#line 1 "parse.y" /* yacc.c:339  */

/*
Copyright (C) 2000-2013  The PARI group.

This file is part of the GP2C package.

PARI/GP is free software; you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation. It is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY WHATSOEVER.

Check the License for details. You should have received a copy of it, along
with the package; see the file 'COPYING'. If not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.*/

#define YYDEBUG 1
#include "config.h"
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include "header.h"
int linecount;
int yyerror(const char *s);
int yylex(void);
static int once=0;
static int newcommand(int x, int y)
{
  return (x==GNOARG)?y:(y==GNOARG)?x:newnode(Fseq,x,y);
}

#line 97 "parse.c" /* yacc.c:339  */

# ifndef YY_NULLPTR
#  if defined __cplusplus && 201103L <= __cplusplus
#   define YY_NULLPTR nullptr
#  else
#   define YY_NULLPTR 0
#  endif
# endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 1
#endif

/* In a future release of Bison, this section will be replaced
   by #include "y.tab.h".  */
#ifndef YY_YY_PARSE_H_INCLUDED
# define YY_YY_PARSE_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int yydebug;
#endif

/* Token type.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    KDOTDOT = 258,
    KPARROW = 259,
    KARROW = 260,
    KPE = 261,
    KSE = 262,
    KME = 263,
    KDE = 264,
    KDRE = 265,
    KEUCE = 266,
    KMODE = 267,
    KAND = 268,
    KOR = 269,
    KID = 270,
    KEQ = 271,
    KNE = 272,
    KGE = 273,
    KLE = 274,
    KSRE = 275,
    KSLE = 276,
    KSR = 277,
    KSL = 278,
    KDR = 279,
    KPP = 280,
    KSS = 281,
    KINTEGER = 282,
    KREAL = 283,
    KENTRY = 284,
    KSTRING = 285,
    SEQ = 286,
    DEFFUNC = 287,
    INT = 288,
    LVAL = 289,
    SIGN = 290,
    MAT = 291
  };
#endif
/* Tokens.  */
#define KDOTDOT 258
#define KPARROW 259
#define KARROW 260
#define KPE 261
#define KSE 262
#define KME 263
#define KDE 264
#define KDRE 265
#define KEUCE 266
#define KMODE 267
#define KAND 268
#define KOR 269
#define KID 270
#define KEQ 271
#define KNE 272
#define KGE 273
#define KLE 274
#define KSRE 275
#define KSLE 276
#define KSR 277
#define KSL 278
#define KDR 279
#define KPP 280
#define KSS 281
#define KINTEGER 282
#define KREAL 283
#define KENTRY 284
#define KSTRING 285
#define SEQ 286
#define DEFFUNC 287
#define INT 288
#define LVAL 289
#define SIGN 290
#define MAT 291

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED

union YYSTYPE
{
#line 32 "parse.y" /* yacc.c:355  */

  int val;
  strcom str;

#line 214 "parse.c" /* yacc.c:355  */
};

typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE yylval;

int yyparse (void);

#endif /* !YY_YY_PARSE_H_INCLUDED  */

/* Copy the second part of user declarations.  */

#line 231 "parse.c" /* yacc.c:358  */

#ifdef short
# undef short
#endif

#ifdef YYTYPE_UINT8
typedef YYTYPE_UINT8 yytype_uint8;
#else
typedef unsigned char yytype_uint8;
#endif

#ifdef YYTYPE_INT8
typedef YYTYPE_INT8 yytype_int8;
#else
typedef signed char yytype_int8;
#endif

#ifdef YYTYPE_UINT16
typedef YYTYPE_UINT16 yytype_uint16;
#else
typedef unsigned short int yytype_uint16;
#endif

#ifdef YYTYPE_INT16
typedef YYTYPE_INT16 yytype_int16;
#else
typedef short int yytype_int16;
#endif

#ifndef YYSIZE_T
# ifdef __SIZE_TYPE__
#  define YYSIZE_T __SIZE_TYPE__
# elif defined size_t
#  define YYSIZE_T size_t
# elif ! defined YYSIZE_T
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# else
#  define YYSIZE_T unsigned int
# endif
#endif

#define YYSIZE_MAXIMUM ((YYSIZE_T) -1)

#ifndef YY_
# if defined YYENABLE_NLS && YYENABLE_NLS
#  if ENABLE_NLS
#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
#  endif
# endif
# ifndef YY_
#  define YY_(Msgid) Msgid
# endif
#endif

#ifndef YY_ATTRIBUTE
# if (defined __GNUC__                                               \
      && (2 < __GNUC__ || (__GNUC__ == 2 && 96 <= __GNUC_MINOR__)))  \
     || defined __SUNPRO_C && 0x5110 <= __SUNPRO_C
#  define YY_ATTRIBUTE(Spec) __attribute__(Spec)
# else
#  define YY_ATTRIBUTE(Spec) /* empty */
# endif
#endif

#ifndef YY_ATTRIBUTE_PURE
# define YY_ATTRIBUTE_PURE   YY_ATTRIBUTE ((__pure__))
#endif

#ifndef YY_ATTRIBUTE_UNUSED
# define YY_ATTRIBUTE_UNUSED YY_ATTRIBUTE ((__unused__))
#endif

#if !defined _Noreturn \
     && (!defined __STDC_VERSION__ || __STDC_VERSION__ < 201112)
# if defined _MSC_VER && 1200 <= _MSC_VER
#  define _Noreturn __declspec (noreturn)
# else
#  define _Noreturn YY_ATTRIBUTE ((__noreturn__))
# endif
#endif

/* Suppress unused-variable warnings by "using" E.  */
#if ! defined lint || defined __GNUC__
# define YYUSE(E) ((void) (E))
#else
# define YYUSE(E) /* empty */
#endif

#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
/* Suppress an incorrect diagnostic about yylval being uninitialized.  */
# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
    _Pragma ("GCC diagnostic push") \
    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")\
    _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
# define YY_IGNORE_MAYBE_UNINITIALIZED_END \
    _Pragma ("GCC diagnostic pop")
#else
# define YY_INITIAL_VALUE(Value) Value
#endif
#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_END
#endif
#ifndef YY_INITIAL_VALUE
# define YY_INITIAL_VALUE(Value) /* Nothing. */
#endif


#if ! defined yyoverflow || YYERROR_VERBOSE

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# ifdef YYSTACK_USE_ALLOCA
#  if YYSTACK_USE_ALLOCA
#   ifdef __GNUC__
#    define YYSTACK_ALLOC __builtin_alloca
#   elif defined __BUILTIN_VA_ARG_INCR
#    include <alloca.h> /* INFRINGES ON USER NAME SPACE */
#   elif defined _AIX
#    define YYSTACK_ALLOC __alloca
#   elif defined _MSC_VER
#    include <malloc.h> /* INFRINGES ON USER NAME SPACE */
#    define alloca _alloca
#   else
#    define YYSTACK_ALLOC alloca
#    if ! defined _ALLOCA_H && ! defined EXIT_SUCCESS
#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
      /* Use EXIT_SUCCESS as a witness for stdlib.h.  */
#     ifndef EXIT_SUCCESS
#      define EXIT_SUCCESS 0
#     endif
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's 'empty if-body' warning.  */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
#  ifndef YYSTACK_ALLOC_MAXIMUM
    /* The OS might guarantee only one guard page at the bottom of the stack,
       and a page size can be as small as 4096 bytes.  So we cannot safely
       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
       to allow for a few compiler-allocated temporary stack slots.  */
#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2006 */
#  endif
# else
#  define YYSTACK_ALLOC YYMALLOC
#  define YYSTACK_FREE YYFREE
#  ifndef YYSTACK_ALLOC_MAXIMUM
#   define YYSTACK_ALLOC_MAXIMUM YYSIZE_MAXIMUM
#  endif
#  if (defined __cplusplus && ! defined EXIT_SUCCESS \
       && ! ((defined YYMALLOC || defined malloc) \
             && (defined YYFREE || defined free)))
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   ifndef EXIT_SUCCESS
#    define EXIT_SUCCESS 0
#   endif
#  endif
#  ifndef YYMALLOC
#   define YYMALLOC malloc
#   if ! defined malloc && ! defined EXIT_SUCCESS
void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
#  ifndef YYFREE
#   define YYFREE free
#   if ! defined free && ! defined EXIT_SUCCESS
void free (void *); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
# endif
#endif /* ! defined yyoverflow || YYERROR_VERBOSE */


#if (! defined yyoverflow \
     && (! defined __cplusplus \
         || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  yytype_int16 yyss_alloc;
  YYSTYPE yyvs_alloc;
};

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (yytype_int16) + sizeof (YYSTYPE)) \
      + YYSTACK_GAP_MAXIMUM)

# define YYCOPY_NEEDED 1

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack_alloc, Stack)                           \
    do                                                                  \
      {                                                                 \
        YYSIZE_T yynewbytes;                                            \
        YYCOPY (&yyptr->Stack_alloc, Stack, yysize);                    \
        Stack = &yyptr->Stack_alloc;                                    \
        yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
        yyptr += yynewbytes / sizeof (*yyptr);                          \
      }                                                                 \
    while (0)

#endif

#if defined YYCOPY_NEEDED && YYCOPY_NEEDED
/* Copy COUNT objects from SRC to DST.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if defined __GNUC__ && 1 < __GNUC__
#   define YYCOPY(Dst, Src, Count) \
      __builtin_memcpy (Dst, Src, (Count) * sizeof (*(Src)))
#  else
#   define YYCOPY(Dst, Src, Count)              \
      do                                        \
        {                                       \
          YYSIZE_T yyi;                         \
          for (yyi = 0; yyi < (Count); yyi++)   \
            (Dst)[yyi] = (Src)[yyi];            \
        }                                       \
      while (0)
#  endif
# endif
#endif /* !YYCOPY_NEEDED */

/* YYFINAL -- State number of the termination state.  */
#define YYFINAL  47
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   723

/* YYNTOKENS -- Number of terminals.  */
#define YYNTOKENS  63
/* YYNNTS -- Number of nonterminals.  */
#define YYNNTS  21
/* YYNRULES -- Number of rules.  */
#define YYNRULES  110
/* YYNSTATES -- Number of states.  */
#define YYNSTATES  194

/* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
   by yylex, with out-of-bounds checking.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   291

#define YYTRANSLATE(YYX)                                                \
  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)

/* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
   as returned by yylex, without out-of-bounds checking.  */
static const yytype_uint8 yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      31,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,    51,     2,    50,     2,    44,    39,    54,
      57,    61,    47,    42,    37,    43,    55,    46,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,    58,    36,
      41,    38,    40,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,    53,    45,    59,    49,     2,    60,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,    62,     2,    52,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    32,    33,    34,    35,
      48,    56
};

#if YYDEBUG
  /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
static const yytype_uint8 yyrline[] =
{
       0,    91,    91,    92,    95,    96,    97,    98,   101,   102,
     103,   104,   107,   108,   111,   112,   115,   116,   117,   118,
     119,   120,   126,   127,   128,   129,   131,   132,   133,   134,
     135,   136,   137,   138,   139,   140,   141,   142,   143,   144,
     145,   146,   147,   148,   149,   150,   151,   152,   153,   154,
     155,   156,   157,   158,   159,   160,   161,   162,   163,   164,
     165,   166,   167,   168,   169,   170,   171,   172,   173,   174,
     175,   176,   177,   178,   179,   180,   181,   182,   183,   186,
     187,   188,   191,   192,   195,   196,   199,   200,   201,   202,
     203,   204,   207,   210,   211,   212,   213,   216,   219,   220,
     221,   222,   222,   226,   227,   230,   233,   236,   238,   240,
     241
};
#endif

#if YYDEBUG || YYERROR_VERBOSE || 1
/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
static const char *const yytname[] =
{
  "$end", "error", "$undefined", "\"..\"", "\")->\"", "\"->\"", "\"+=\"",
  "\"-=\"", "\"*=\"", "\"/=\"", "\"\\\\/=\"", "\"\\\\=\"", "\"%=\"",
  "\"&&\"", "\"||\"", "\"===\"", "\"==\"", "\"!=\"", "\">=\"", "\"<=\"",
  "\">>=\"", "\"<<=\"", "\">>\"", "\"<<\"", "\"\\\\/\"", "\"++\"",
  "\"--\"", "\"integer\"", "\"real number\"", "\"variable name\"",
  "\"character string\"", "'\\n'", "SEQ", "DEFFUNC", "INT", "LVAL", "';'",
  "','", "'='", "'&'", "'>'", "'<'", "'+'", "'-'", "'%'", "'\\\\'", "'/'",
  "'*'", "SIGN", "'^'", "'#'", "'!'", "'~'", "'['", "'\\''", "'.'", "MAT",
  "'('", "':'", "']'", "'`'", "')'", "'|'", "$accept", "commands", "seq",
  "range", "matrix_index", "backticks", "history", "expr", "lvalue",
  "matrixelts", "matrixlines", "matrix", "in", "inseq", "compr", "arg",
  "$@1", "listarg", "funcid", "memberid", "definition", YY_NULLPTR
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[NUM] -- (External) token number corresponding to the
   (internal) symbol number NUM (which must be that of a token).  */
static const yytype_uint16 yytoknum[] =
{
       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
     285,    10,   286,   287,   288,   289,    59,    44,    61,    38,
      62,    60,    43,    45,    37,    92,    47,    42,   290,    94,
      35,    33,   126,    91,    39,    46,   291,    40,    58,    93,
      96,    41,   124
};
# endif

#define YYPACT_NINF -168

#define yypact_value_is_default(Yystate) \
  (!!((Yystate) == (-168)))

#define YYTABLE_NINF -105

#define yytable_value_is_error(Yytable_value) \
  0

  /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
     STATE-NUM.  */
static const yytype_int16 yypact[] =
{
     666,   -32,  -168,   -18,  -168,   666,   666,    44,   666,   666,
     101,     2,  -168,   630,    10,     7,  -168,   502,   312,    35,
    -168,    45,    46,  -168,    57,   630,   150,   150,  -168,   -20,
    -168,    27,   201,    55,    32,    33,  -168,   174,   -22,    34,
    -168,    67,     7,   360,   334,    28,     5,  -168,   666,   666,
     666,   666,   666,   666,   666,   666,   666,   666,   666,   666,
     666,   666,   666,   666,   666,   666,   666,   666,   666,   666,
    -168,  -168,   648,  -168,    77,   630,    78,  -168,   666,   666,
     666,   666,   666,   666,   666,   666,   666,   666,  -168,  -168,
     666,    82,  -168,   666,   666,   666,  -168,   -26,  -168,    27,
    -168,  -168,  -168,   666,    67,   666,   666,  -168,   666,  -168,
    -168,   -34,  -168,   259,  -168,   666,   630,     7,   502,   546,
     546,   583,   583,   583,   583,   583,   150,   150,   150,   546,
     583,   583,   598,   598,   150,   150,   150,   150,   150,   666,
     -21,   227,  -168,   -25,  -168,     7,   502,   502,   502,   502,
     502,   502,   502,   502,   502,   502,  -168,   502,     7,     7,
    -168,   409,    64,   -10,    59,   502,    83,   502,    83,    60,
     666,     7,    29,   502,   648,  -168,   666,  -168,  -168,    71,
      67,   666,  -168,  -168,   502,    62,   502,   666,  -168,   456,
    -168,   502,    67,  -168
};

  /* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
     Performed when YYTABLE does not specify something else to do.  Zero
     means the default is an error.  */
static const yytype_uint8 yydefact[] =
{
       4,    22,    23,    79,    26,     0,     0,    16,     0,     0,
       0,     0,    24,     4,     0,     2,    28,     5,    31,    32,
      33,    30,    76,    34,     0,     4,    69,    70,    17,    19,
      14,    18,    49,    48,     0,     0,    86,    82,     0,     0,
      27,     0,    98,     5,    31,     0,     0,     1,     4,     6,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
      74,    72,     8,    73,     0,     4,     0,    75,     4,     0,
       0,     0,     0,     0,     0,     0,     0,     0,    37,    38,
       0,     0,    80,     0,     4,     4,    25,     0,    20,    21,
      15,    91,    88,     0,     0,     0,     0,    89,     0,    90,
      79,   100,    78,     8,   101,     4,     4,     3,     7,    51,
      50,    53,    54,    55,    56,    58,    63,    62,    65,    52,
      57,    59,    61,    60,    64,    66,    67,    68,    71,     0,
       0,     9,   106,     0,    77,   109,    46,    47,    39,    40,
      41,    42,    43,    45,    44,    36,    81,    35,   107,   108,
     105,     0,     0,    93,     0,    82,    84,    83,    85,     0,
       0,   110,     0,    11,     8,    13,     0,    29,    87,     0,
       0,     0,    97,    99,   102,     0,    10,     0,    95,    94,
      12,    92,     0,    96
};

  /* YYPGOTO[NTERM-NUM].  */
static const yytype_int16 yypgoto[] =
{
    -168,  -168,    21,   -51,   -16,    95,  -168,    -5,    -7,   -88,
    -168,  -168,  -168,  -167,  -168,     9,  -168,    -3,  -168,  -168,
    -168
};

  /* YYDEFGOTO[NTERM-NUM].  */
static const yytype_int16 yydefgoto[] =
{
      -1,    14,    42,   140,    77,    31,    16,    17,    18,    38,
      39,    19,   163,   164,    20,    45,   170,    46,    21,    22,
      23
};

  /* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
     positive, shift that token.  If negative, reduce the rule whose
     number is the opposite.  If YYTABLE_NINF, syntax error.  */
static const yytype_int16 yytable[] =
{
      26,    27,    92,    32,    33,    37,    44,    98,    43,   115,
      47,   116,   116,   188,   105,   106,   174,   166,    44,    72,
     168,    15,    97,    24,    91,   193,   180,   181,    92,   114,
     114,    40,  -103,  -104,   111,   160,   177,   107,   175,    25,
      30,    48,   116,    49,   118,   119,   120,   121,   122,   123,
     124,   125,   126,   127,   128,   129,   130,   131,   132,   133,
     134,   135,   136,   137,   138,  -103,  -104,   141,    44,   117,
     108,    28,   143,    93,   146,   147,   148,   149,   150,   151,
     152,   153,   154,    94,    95,   155,    96,   100,   157,  -103,
    -104,   101,   102,   109,    29,    92,   110,   162,   161,   145,
     165,   167,    34,   165,    30,   179,   142,   144,   141,    44,
      74,   156,    75,    76,   187,   158,   159,    72,   182,   183,
     106,   190,    91,   185,    99,   172,     0,     0,     1,     2,
       3,     4,     0,     0,   173,     0,   171,    35,     0,     0,
       0,     0,     0,     5,     6,     7,    92,     0,     0,     0,
       0,     8,     9,     0,    10,    11,    12,     0,    13,     0,
      36,     0,     0,     0,     0,   184,     0,     0,     0,   141,
       0,   186,     0,   162,     0,     0,   189,   103,     0,     0,
       0,     0,   191,     0,     0,   162,     0,    50,    51,    52,
      53,    54,    55,    56,     0,     0,    57,    58,    59,    69,
       0,    70,    71,    72,    73,    74,     0,    75,    76,     0,
       0,     0,     0,    60,    61,    62,    63,    64,    65,    66,
      67,    68,     0,    69,     0,    70,    71,    72,    73,    74,
     176,    75,    76,     0,     0,     0,   104,     0,     0,     0,
      50,    51,    52,    53,    54,    55,    56,     0,     0,    57,
      58,    59,    70,    71,    72,    73,    74,     0,    75,    76,
       0,     0,   169,     0,     0,     0,    60,    61,    62,    63,
      64,    65,    66,    67,    68,     0,    69,     0,    70,    71,
      72,    73,    74,     0,    75,    76,     1,     2,     3,     4,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     5,     6,     7,     0,     0,     0,     0,   139,     8,
       9,     0,    10,    11,    12,     0,    13,    78,    79,    80,
      81,    82,    83,    84,    85,     0,     0,     0,     0,     0,
       0,     0,    86,    87,     0,     0,     0,    88,    89,    78,
      79,    80,    81,    82,    83,    84,    85,     0,     0,     0,
      90,     0,     0,     0,    86,    87,     0,     0,     0,    88,
      89,     0,     0,     0,     0,    72,     0,     0,     0,     0,
      91,     0,    90,    50,    51,    52,    53,    54,    55,    56,
       0,     0,    57,    58,    59,     0,     0,   113,     0,     0,
       0,     0,    91,     0,     0,     0,     0,     0,     0,    60,
      61,    62,    63,    64,    65,    66,    67,    68,     0,    69,
       0,    70,    71,    72,    73,    74,     0,    75,    76,     0,
       0,   112,    50,    51,    52,    53,    54,    55,    56,     0,
       0,    57,    58,    59,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,    60,    61,
      62,    63,    64,    65,    66,    67,    68,     0,    69,     0,
      70,    71,    72,    73,    74,     0,    75,    76,   178,    50,
      51,    52,    53,    54,    55,    56,     0,     0,    57,    58,
      59,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,   192,     0,     0,    60,    61,    62,    63,    64,
      65,    66,    67,    68,     0,    69,     0,    70,    71,    72,
      73,    74,     0,    75,    76,    50,    51,    52,    53,    54,
      55,    56,     0,     0,    57,    58,    59,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,    60,    61,    62,    63,    64,    65,    66,    67,    68,
       0,    69,     0,    70,    71,    72,    73,    74,     0,    75,
      76,    52,    53,    54,    55,    56,     0,     0,    57,    58,
      59,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,    61,    62,    63,    64,
      65,    66,    67,    68,     0,    69,     0,    70,    71,    72,
      73,    74,     0,    75,    76,    57,    58,    59,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
      57,    58,    59,     0,     0,    63,    64,    65,    66,    67,
      68,     0,    69,     0,    70,    71,    72,    73,    74,     0,
      75,    76,    65,    66,    67,    68,     0,    69,     0,    70,
      71,    72,    73,    74,     0,    75,    76,     1,     2,     3,
       4,     0,     0,     0,     0,     0,     0,     0,     0,    41,
       0,     0,     5,     6,     7,     1,     2,     3,     4,     0,
       8,     9,     0,    10,    11,    12,     0,    13,     0,     0,
       5,     6,     7,     1,     2,     3,     4,   139,     8,     9,
       0,    10,    11,    12,     0,    13,     0,     0,     5,     6,
       7,     0,     0,     0,     0,     0,     8,     9,     0,    10,
      11,    12,     0,    13
};

static const yytype_int16 yycheck[] =
{
       5,     6,    18,     8,     9,    10,    13,    27,    13,     4,
       0,    37,    37,   180,    36,    37,    37,   105,    25,    53,
     108,     0,    25,    55,    58,   192,    36,    37,    44,     1,
       1,    29,     4,     4,    41,    61,    61,    59,    59,    57,
      60,    31,    37,    36,    49,    50,    51,    52,    53,    54,
      55,    56,    57,    58,    59,    60,    61,    62,    63,    64,
      65,    66,    67,    68,    69,    37,    37,    72,    75,    48,
      36,    27,    75,    38,    79,    80,    81,    82,    83,    84,
      85,    86,    87,    38,    38,    90,    29,    60,    93,    61,
      61,    59,    59,    59,    50,   111,    29,   104,   103,    78,
     105,   106,     1,   108,    60,    41,    29,    29,   113,   116,
      55,    29,    57,    58,    43,    94,    95,    53,    59,    59,
      37,    59,    58,   174,    29,   116,    -1,    -1,    27,    28,
      29,    30,    -1,    -1,   139,    -1,   115,    36,    -1,    -1,
      -1,    -1,    -1,    42,    43,    44,   162,    -1,    -1,    -1,
      -1,    50,    51,    -1,    53,    54,    55,    -1,    57,    -1,
      59,    -1,    -1,    -1,    -1,   170,    -1,    -1,    -1,   174,
      -1,   176,    -1,   180,    -1,    -1,   181,     3,    -1,    -1,
      -1,    -1,   187,    -1,    -1,   192,    -1,    13,    14,    15,
      16,    17,    18,    19,    -1,    -1,    22,    23,    24,    49,
      -1,    51,    52,    53,    54,    55,    -1,    57,    58,    -1,
      -1,    -1,    -1,    39,    40,    41,    42,    43,    44,    45,
      46,    47,    -1,    49,    -1,    51,    52,    53,    54,    55,
       3,    57,    58,    -1,    -1,    -1,    62,    -1,    -1,    -1,
      13,    14,    15,    16,    17,    18,    19,    -1,    -1,    22,
      23,    24,    51,    52,    53,    54,    55,    -1,    57,    58,
      -1,    -1,     3,    -1,    -1,    -1,    39,    40,    41,    42,
      43,    44,    45,    46,    47,    -1,    49,    -1,    51,    52,
      53,    54,    55,    -1,    57,    58,    27,    28,    29,    30,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    42,    43,    44,    -1,    -1,    -1,    -1,    49,    50,
      51,    -1,    53,    54,    55,    -1,    57,     5,     6,     7,
       8,     9,    10,    11,    12,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    20,    21,    -1,    -1,    -1,    25,    26,     5,
       6,     7,     8,     9,    10,    11,    12,    -1,    -1,    -1,
      38,    -1,    -1,    -1,    20,    21,    -1,    -1,    -1,    25,
      26,    -1,    -1,    -1,    -1,    53,    -1,    -1,    -1,    -1,
      58,    -1,    38,    13,    14,    15,    16,    17,    18,    19,
      -1,    -1,    22,    23,    24,    -1,    -1,    53,    -1,    -1,
      -1,    -1,    58,    -1,    -1,    -1,    -1,    -1,    -1,    39,
      40,    41,    42,    43,    44,    45,    46,    47,    -1,    49,
      -1,    51,    52,    53,    54,    55,    -1,    57,    58,    -1,
      -1,    61,    13,    14,    15,    16,    17,    18,    19,    -1,
      -1,    22,    23,    24,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    39,    40,
      41,    42,    43,    44,    45,    46,    47,    -1,    49,    -1,
      51,    52,    53,    54,    55,    -1,    57,    58,    59,    13,
      14,    15,    16,    17,    18,    19,    -1,    -1,    22,    23,
      24,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    36,    -1,    -1,    39,    40,    41,    42,    43,
      44,    45,    46,    47,    -1,    49,    -1,    51,    52,    53,
      54,    55,    -1,    57,    58,    13,    14,    15,    16,    17,
      18,    19,    -1,    -1,    22,    23,    24,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    39,    40,    41,    42,    43,    44,    45,    46,    47,
      -1,    49,    -1,    51,    52,    53,    54,    55,    -1,    57,
      58,    15,    16,    17,    18,    19,    -1,    -1,    22,    23,
      24,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    40,    41,    42,    43,
      44,    45,    46,    47,    -1,    49,    -1,    51,    52,    53,
      54,    55,    -1,    57,    58,    22,    23,    24,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      22,    23,    24,    -1,    -1,    42,    43,    44,    45,    46,
      47,    -1,    49,    -1,    51,    52,    53,    54,    55,    -1,
      57,    58,    44,    45,    46,    47,    -1,    49,    -1,    51,
      52,    53,    54,    55,    -1,    57,    58,    27,    28,    29,
      30,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    39,
      -1,    -1,    42,    43,    44,    27,    28,    29,    30,    -1,
      50,    51,    -1,    53,    54,    55,    -1,    57,    -1,    -1,
      42,    43,    44,    27,    28,    29,    30,    49,    50,    51,
      -1,    53,    54,    55,    -1,    57,    -1,    -1,    42,    43,
      44,    -1,    -1,    -1,    -1,    -1,    50,    51,    -1,    53,
      54,    55,    -1,    57
};

  /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
     symbol of state STATE-NUM.  */
static const yytype_uint8 yystos[] =
{
       0,    27,    28,    29,    30,    42,    43,    44,    50,    51,
      53,    54,    55,    57,    64,    65,    69,    70,    71,    74,
      77,    81,    82,    83,    55,    57,    70,    70,    27,    50,
      60,    68,    70,    70,     1,    36,    59,    70,    72,    73,
      29,    39,    65,    70,    71,    78,    80,     0,    31,    36,
      13,    14,    15,    16,    17,    18,    19,    22,    23,    24,
      39,    40,    41,    42,    43,    44,    45,    46,    47,    49,
      51,    52,    53,    54,    55,    57,    58,    67,     5,     6,
       7,     8,     9,    10,    11,    12,    20,    21,    25,    26,
      38,    58,    67,    38,    38,    38,    29,    80,    27,    68,
      60,    59,    59,     3,    62,    36,    37,    59,    36,    59,
      29,    71,    61,    53,     1,     4,    37,    65,    70,    70,
      70,    70,    70,    70,    70,    70,    70,    70,    70,    70,
      70,    70,    70,    70,    70,    70,    70,    70,    70,    49,
      66,    70,    29,    80,    29,    65,    70,    70,    70,    70,
      70,    70,    70,    70,    70,    70,    29,    70,    65,    65,
      61,    70,    71,    75,    76,    70,    72,    70,    72,     3,
      79,    65,    78,    70,    37,    59,     3,    61,    59,    41,
      36,    37,    59,    59,    70,    66,    70,    43,    76,    70,
      59,    70,    36,    76
};

  /* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const yytype_uint8 yyr1[] =
{
       0,    63,    64,    64,    65,    65,    65,    65,    66,    66,
      66,    66,    67,    67,    68,    68,    69,    69,    69,    69,
      69,    69,    70,    70,    70,    70,    70,    70,    70,    70,
      70,    70,    70,    70,    70,    70,    70,    70,    70,    70,
      70,    70,    70,    70,    70,    70,    70,    70,    70,    70,
      70,    70,    70,    70,    70,    70,    70,    70,    70,    70,
      70,    70,    70,    70,    70,    70,    70,    70,    70,    70,
      70,    70,    70,    70,    70,    70,    70,    70,    70,    71,
      71,    71,    72,    72,    73,    73,    74,    74,    74,    74,
      74,    74,    75,    76,    76,    76,    76,    77,    78,    78,
      78,    79,    78,    80,    80,    81,    82,    83,    83,    83,
      83
};

  /* YYR2[YYN] -- Number of symbols on the right hand side of rule YYN.  */
static const yytype_uint8 yyr2[] =
{
       0,     2,     1,     3,     0,     1,     2,     3,     0,     1,
       3,     2,     5,     3,     1,     2,     1,     2,     2,     2,
       3,     3,     1,     1,     1,     3,     1,     2,     1,     4,
       1,     1,     1,     1,     1,     3,     3,     2,     2,     3,
       3,     3,     3,     3,     3,     3,     3,     3,     2,     2,
       3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
       3,     3,     3,     3,     3,     3,     3,     3,     3,     2,
       2,     3,     2,     2,     2,     2,     1,     3,     3,     1,
       2,     3,     1,     3,     3,     3,     2,     5,     3,     3,
       3,     3,     4,     1,     3,     3,     5,     5,     1,     4,
       2,     0,     4,     1,     3,     4,     3,     3,     3,     3,
       4
};


#define yyerrok         (yyerrstatus = 0)
#define yyclearin       (yychar = YYEMPTY)
#define YYEMPTY         (-2)
#define YYEOF           0

#define YYACCEPT        goto yyacceptlab
#define YYABORT         goto yyabortlab
#define YYERROR         goto yyerrorlab


#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)                                  \
do                                                              \
  if (yychar == YYEMPTY)                                        \
    {                                                           \
      yychar = (Token);                                         \
      yylval = (Value);                                         \
      YYPOPSTACK (yylen);                                       \
      yystate = *yyssp;                                         \
      goto yybackup;                                            \
    }                                                           \
  else                                                          \
    {                                                           \
      yyerror (YY_("syntax error: cannot back up")); \
      YYERROR;                                                  \
    }                                                           \
while (0)

/* Error token number */
#define YYTERROR        1
#define YYERRCODE       256



/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)                        \
do {                                            \
  if (yydebug)                                  \
    YYFPRINTF Args;                             \
} while (0)

/* This macro is provided for backward compatibility. */
#ifndef YY_LOCATION_PRINT
# define YY_LOCATION_PRINT(File, Loc) ((void) 0)
#endif


# define YY_SYMBOL_PRINT(Title, Type, Value, Location)                    \
do {                                                                      \
  if (yydebug)                                                            \
    {                                                                     \
      YYFPRINTF (stderr, "%s ", Title);                                   \
      yy_symbol_print (stderr,                                            \
                  Type, Value); \
      YYFPRINTF (stderr, "\n");                                           \
    }                                                                     \
} while (0)


/*----------------------------------------.
| Print this symbol's value on YYOUTPUT.  |
`----------------------------------------*/

static void
yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
{
  FILE *yyo = yyoutput;
  YYUSE (yyo);
  if (!yyvaluep)
    return;
# ifdef YYPRINT
  if (yytype < YYNTOKENS)
    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
# endif
  YYUSE (yytype);
}


/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

static void
yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
{
  YYFPRINTF (yyoutput, "%s %s (",
             yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);

  yy_symbol_value_print (yyoutput, yytype, yyvaluep);
  YYFPRINTF (yyoutput, ")");
}

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (included).                                                   |
`------------------------------------------------------------------*/

static void
yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
{
  YYFPRINTF (stderr, "Stack now");
  for (; yybottom <= yytop; yybottom++)
    {
      int yybot = *yybottom;
      YYFPRINTF (stderr, " %d", yybot);
    }
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)                            \
do {                                                            \
  if (yydebug)                                                  \
    yy_stack_print ((Bottom), (Top));                           \
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

static void
yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule)
{
  unsigned long int yylno = yyrline[yyrule];
  int yynrhs = yyr2[yyrule];
  int yyi;
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
             yyrule - 1, yylno);
  /* The symbols being reduced.  */
  for (yyi = 0; yyi < yynrhs; yyi++)
    {
      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
      yy_symbol_print (stderr,
                       yystos[yyssp[yyi + 1 - yynrhs]],
                       &(yyvsp[(yyi + 1) - (yynrhs)])
                                              );
      YYFPRINTF (stderr, "\n");
    }
}

# define YY_REDUCE_PRINT(Rule)          \
do {                                    \
  if (yydebug)                          \
    yy_reduce_print (yyssp, yyvsp, Rule); \
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args)
# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif


#if YYERROR_VERBOSE

# ifndef yystrlen
#  if defined __GLIBC__ && defined _STRING_H
#   define yystrlen strlen
#  else
/* Return the length of YYSTR.  */
static YYSIZE_T
yystrlen (const char *yystr)
{
  YYSIZE_T yylen;
  for (yylen = 0; yystr[yylen]; yylen++)
    continue;
  return yylen;
}
#  endif
# endif

# ifndef yystpcpy
#  if defined __GLIBC__ && defined _STRING_H && defined _GNU_SOURCE
#   define yystpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
static char *
yystpcpy (char *yydest, const char *yysrc)
{
  char *yyd = yydest;
  const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
#  endif
# endif

# ifndef yytnamerr
/* Copy to YYRES the contents of YYSTR after stripping away unnecessary
   quotes and backslashes, so that it's suitable for yyerror.  The
   heuristic is that double-quoting is unnecessary unless the string
   contains an apostrophe, a comma, or backslash (other than
   backslash-backslash).  YYSTR is taken from yytname.  If YYRES is
   null, do not copy; instead, return the length of what the result
   would have been.  */
static YYSIZE_T
yytnamerr (char *yyres, const char *yystr)
{
  if (*yystr == '"')
    {
      YYSIZE_T yyn = 0;
      char const *yyp = yystr;

      for (;;)
        switch (*++yyp)
          {
          case '\'':
          case ',':
            goto do_not_strip_quotes;

          case '\\':
            if (*++yyp != '\\')
              goto do_not_strip_quotes;
            /* Fall through.  */
          default:
            if (yyres)
              yyres[yyn] = *yyp;
            yyn++;
            break;

          case '"':
            if (yyres)
              yyres[yyn] = '\0';
            return yyn;
          }
    do_not_strip_quotes: ;
    }

  if (! yyres)
    return yystrlen (yystr);

  return yystpcpy (yyres, yystr) - yyres;
}
# endif

/* Copy into *YYMSG, which is of size *YYMSG_ALLOC, an error message
   about the unexpected token YYTOKEN for the state stack whose top is
   YYSSP.

   Return 0 if *YYMSG was successfully written.  Return 1 if *YYMSG is
   not large enough to hold the message.  In that case, also set
   *YYMSG_ALLOC to the required number of bytes.  Return 2 if the
   required number of bytes is too large to store.  */
static int
yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                yytype_int16 *yyssp, int yytoken)
{
  YYSIZE_T yysize0 = yytnamerr (YY_NULLPTR, yytname[yytoken]);
  YYSIZE_T yysize = yysize0;
  enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
  /* Internationalized format string. */
  const char *yyformat = YY_NULLPTR;
  /* Arguments of yyformat. */
  char const *yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
  /* Number of reported tokens (one for the "unexpected", one per
     "expected"). */
  int yycount = 0;

  /* There are many possibilities here to consider:
     - If this state is a consistent state with a default action, then
       the only way this function was invoked is if the default action
       is an error action.  In that case, don't check for expected
       tokens because there are none.
     - The only way there can be no lookahead present (in yychar) is if
       this state is a consistent state with a default action.  Thus,
       detecting the absence of a lookahead is sufficient to determine
       that there is no unexpected or expected token to report.  In that
       case, just report a simple "syntax error".
     - Don't assume there isn't a lookahead just because this state is a
       consistent state with a default action.  There might have been a
       previous inconsistent state, consistent state with a non-default
       action, or user semantic action that manipulated yychar.
     - Of course, the expected token list depends on states to have
       correct lookahead information, and it depends on the parser not
       to perform extra reductions after fetching a lookahead from the
       scanner and before detecting a syntax error.  Thus, state merging
       (from LALR or IELR) and default reductions corrupt the expected
       token list.  However, the list is correct for canonical LR with
       one exception: it will still contain any token that will not be
       accepted due to an error action in a later state.
  */
  if (yytoken != YYEMPTY)
    {
      int yyn = yypact[*yyssp];
      yyarg[yycount++] = yytname[yytoken];
      if (!yypact_value_is_default (yyn))
        {
          /* Start YYX at -YYN if negative to avoid negative indexes in
             YYCHECK.  In other words, skip the first -YYN actions for
             this state because they are default actions.  */
          int yyxbegin = yyn < 0 ? -yyn : 0;
          /* Stay within bounds of both yycheck and yytname.  */
          int yychecklim = YYLAST - yyn + 1;
          int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
          int yyx;

          for (yyx = yyxbegin; yyx < yyxend; ++yyx)
            if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR
                && !yytable_value_is_error (yytable[yyx + yyn]))
              {
                if (yycount == YYERROR_VERBOSE_ARGS_MAXIMUM)
                  {
                    yycount = 1;
                    yysize = yysize0;
                    break;
                  }
                yyarg[yycount++] = yytname[yyx];
                {
                  YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
                  if (! (yysize <= yysize1
                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
                    return 2;
                  yysize = yysize1;
                }
              }
        }
    }

  switch (yycount)
    {
# define YYCASE_(N, S)                      \
      case N:                               \
        yyformat = S;                       \
      break
      YYCASE_(0, YY_("syntax error"));
      YYCASE_(1, YY_("syntax error, unexpected %s"));
      YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
      YYCASE_(3, YY_("syntax error, unexpected %s, expecting %s or %s"));
      YYCASE_(4, YY_("syntax error, unexpected %s, expecting %s or %s or %s"));
      YYCASE_(5, YY_("syntax error, unexpected %s, expecting %s or %s or %s or %s"));
# undef YYCASE_
    }

  {
    YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
      return 2;
    yysize = yysize1;
  }

  if (*yymsg_alloc < yysize)
    {
      *yymsg_alloc = 2 * yysize;
      if (! (yysize <= *yymsg_alloc
             && *yymsg_alloc <= YYSTACK_ALLOC_MAXIMUM))
        *yymsg_alloc = YYSTACK_ALLOC_MAXIMUM;
      return 1;
    }

  /* Avoid sprintf, as that infringes on the user's name space.
     Don't have undefined behavior even if the translation
     produced a string with the wrong number of "%s"s.  */
  {
    char *yyp = *yymsg;
    int yyi = 0;
    while ((*yyp = *yyformat) != '\0')
      if (*yyp == '%' && yyformat[1] == 's' && yyi < yycount)
        {
          yyp += yytnamerr (yyp, yyarg[yyi++]);
          yyformat += 2;
        }
      else
        {
          yyp++;
          yyformat++;
        }
  }
  return 0;
}
#endif /* YYERROR_VERBOSE */

/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

static void
yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep)
{
  YYUSE (yyvaluep);
  if (!yymsg)
    yymsg = "Deleting";
  YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  YYUSE (yytype);
  YY_IGNORE_MAYBE_UNINITIALIZED_END
}




/* The lookahead symbol.  */
int yychar;

/* The semantic value of the lookahead symbol.  */
YYSTYPE yylval;
/* Number of syntax errors so far.  */
int yynerrs;


/*----------.
| yyparse.  |
`----------*/

int
yyparse (void)
{
    int yystate;
    /* Number of tokens to shift before error messages enabled.  */
    int yyerrstatus;

    /* The stacks and their tools:
       'yyss': related to states.
       'yyvs': related to semantic values.

       Refer to the stacks through separate pointers, to allow yyoverflow
       to reallocate them elsewhere.  */

    /* The state stack.  */
    yytype_int16 yyssa[YYINITDEPTH];
    yytype_int16 *yyss;
    yytype_int16 *yyssp;

    /* The semantic value stack.  */
    YYSTYPE yyvsa[YYINITDEPTH];
    YYSTYPE *yyvs;
    YYSTYPE *yyvsp;

    YYSIZE_T yystacksize;

  int yyn;
  int yyresult;
  /* Lookahead token as an internal (translated) token number.  */
  int yytoken = 0;
  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;

#if YYERROR_VERBOSE
  /* Buffer for error messages, and its allocated size.  */
  char yymsgbuf[128];
  char *yymsg = yymsgbuf;
  YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
#endif

#define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))

  /* The number of symbols on the RHS of the reduced rule.
     Keep to zero when no symbol should be popped.  */
  int yylen = 0;

  yyssp = yyss = yyssa;
  yyvsp = yyvs = yyvsa;
  yystacksize = YYINITDEPTH;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY; /* Cause a token to be read.  */
  goto yysetstate;

/*------------------------------------------------------------.
| yynewstate -- Push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
 yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed.  So pushing a state here evens the stacks.  */
  yyssp++;

 yysetstate:
  *yyssp = yystate;

  if (yyss + yystacksize - 1 <= yyssp)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T yysize = yyssp - yyss + 1;

#ifdef yyoverflow
      {
        /* Give user a chance to reallocate the stack.  Use copies of
           these so that the &'s don't force the real ones into
           memory.  */
        YYSTYPE *yyvs1 = yyvs;
        yytype_int16 *yyss1 = yyss;

        /* Each stack pointer address is followed by the size of the
           data in use in that stack, in bytes.  This used to be a
           conditional around just the two extra args, but that might
           be undefined if yyoverflow is a macro.  */
        yyoverflow (YY_("memory exhausted"),
                    &yyss1, yysize * sizeof (*yyssp),
                    &yyvs1, yysize * sizeof (*yyvsp),
                    &yystacksize);

        yyss = yyss1;
        yyvs = yyvs1;
      }
#else /* no yyoverflow */
# ifndef YYSTACK_RELOCATE
      goto yyexhaustedlab;
# else
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
        goto yyexhaustedlab;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
        yystacksize = YYMAXDEPTH;

      {
        yytype_int16 *yyss1 = yyss;
        union yyalloc *yyptr =
          (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
        if (! yyptr)
          goto yyexhaustedlab;
        YYSTACK_RELOCATE (yyss_alloc, yyss);
        YYSTACK_RELOCATE (yyvs_alloc, yyvs);
#  undef YYSTACK_RELOCATE
        if (yyss1 != yyssa)
          YYSTACK_FREE (yyss1);
      }
# endif
#endif /* no yyoverflow */

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;

      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
                  (unsigned long int) yystacksize));

      if (yyss + yystacksize - 1 <= yyssp)
        YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", yystate));

  if (yystate == YYFINAL)
    YYACCEPT;

  goto yybackup;

/*-----------.
| yybackup.  |
`-----------*/
yybackup:

  /* Do appropriate processing given the current state.  Read a
     lookahead token if we need one and don't already have one.  */

  /* First try to decide what to do without reference to lookahead token.  */
  yyn = yypact[yystate];
  if (yypact_value_is_default (yyn))
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token: "));
      yychar = yylex ();
    }

  if (yychar <= YYEOF)
    {
      yychar = yytoken = YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yytable_value_is_error (yyn))
        goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  /* Shift the lookahead token.  */
  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);

  /* Discard the shifted token.  */
  yychar = YYEMPTY;

  yystate = yyn;
  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END

  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- Do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     '$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
        case 2:
#line 91 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=(yyvsp[0].val);}
#line 1554 "parse.c" /* yacc.c:1646  */
    break;

  case 3:
#line 92 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newcommand((yyvsp[-2].val),(yyvsp[0].val));}
#line 1560 "parse.c" /* yacc.c:1646  */
    break;

  case 4:
#line 95 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=GNOARG;}
#line 1566 "parse.c" /* yacc.c:1646  */
    break;

  case 5:
#line 96 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=(yyvsp[0].val);}
#line 1572 "parse.c" /* yacc.c:1646  */
    break;

  case 6:
#line 97 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=(yyvsp[-1].val);}
#line 1578 "parse.c" /* yacc.c:1646  */
    break;

  case 7:
#line 98 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newcommand((yyvsp[-2].val),(yyvsp[0].val));}
#line 1584 "parse.c" /* yacc.c:1646  */
    break;

  case 8:
#line 101 "parse.y" /* yacc.c:1646  */
    { (yyval.val)=newnode(Frange,GNORANGE,GNORANGE); }
#line 1590 "parse.c" /* yacc.c:1646  */
    break;

  case 9:
#line 102 "parse.y" /* yacc.c:1646  */
    { (yyval.val)=newnode(Frange,(yyvsp[0].val),GNORANGE); }
#line 1596 "parse.c" /* yacc.c:1646  */
    break;

  case 10:
#line 103 "parse.y" /* yacc.c:1646  */
    { (yyval.val)=newnode(Frange,(yyvsp[-2].val),(yyvsp[0].val)); }
#line 1602 "parse.c" /* yacc.c:1646  */
    break;

  case 11:
#line 104 "parse.y" /* yacc.c:1646  */
    { (yyval.val)=newnode(Frange,GNORANGE,(yyvsp[0].val)); }
#line 1608 "parse.c" /* yacc.c:1646  */
    break;

  case 12:
#line 107 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Fmatrix,(yyvsp[-3].val),(yyvsp[-1].val));}
#line 1614 "parse.c" /* yacc.c:1646  */
    break;

  case 13:
#line 108 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Fmatrix,(yyvsp[-1].val),-1);}
#line 1620 "parse.c" /* yacc.c:1646  */
    break;

  case 14:
#line 111 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=1;}
#line 1626 "parse.c" /* yacc.c:1646  */
    break;

  case 15:
#line 112 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=(yyvsp[-1].val)+1;}
#line 1632 "parse.c" /* yacc.c:1646  */
    break;

  case 16:
#line 115 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPhist,-1,-1);}
#line 1638 "parse.c" /* yacc.c:1646  */
    break;

  case 17:
#line 116 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPhist,newintnode((yyvsp[0].str).s,(yyvsp[0].str).c),-1);}
#line 1644 "parse.c" /* yacc.c:1646  */
    break;

  case 18:
#line 117 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPhist,newnode(Fsmall,-(yyvsp[0].val),-1),-1);}
#line 1650 "parse.c" /* yacc.c:1646  */
    break;

  case 19:
#line 118 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPhisttime,-1,-1);}
#line 1656 "parse.c" /* yacc.c:1646  */
    break;

  case 20:
#line 119 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPhisttime,newintnode((yyvsp[0].str).s,(yyvsp[0].str).c),-1);}
#line 1662 "parse.c" /* yacc.c:1646  */
    break;

  case 21:
#line 120 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPhisttime,newnode(Fsmall,-(yyvsp[0].val),-1),-1);}
#line 1668 "parse.c" /* yacc.c:1646  */
    break;

  case 22:
#line 126 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newintnode((yyvsp[0].str).s,(yyvsp[0].str).c);}
#line 1674 "parse.c" /* yacc.c:1646  */
    break;

  case 23:
#line 127 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newrealnode((yyvsp[0].str).s,(yyvsp[0].str).c);}
#line 1680 "parse.c" /* yacc.c:1646  */
    break;

  case 24:
#line 128 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Fconst,newsmallrealvalue(0),-1);}
#line 1686 "parse.c" /* yacc.c:1646  */
    break;

  case 25:
#line 129 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnodecom(Ffunction,newmember((yyvsp[0].str).s),newintnode((yyvsp[-2].str).s,(yyvsp[-2].str).c),
                                                   (yyvsp[0].str).c);}
#line 1693 "parse.c" /* yacc.c:1646  */
    break;

  case 26:
#line 131 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newstringnode((yyvsp[0].str).s,(yyvsp[0].str).c);}
#line 1699 "parse.c" /* yacc.c:1646  */
    break;

  case 27:
#line 132 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newquotenode((yyvsp[0].str).s,(yyvsp[0].str).c);}
#line 1705 "parse.c" /* yacc.c:1646  */
    break;

  case 28:
#line 133 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=(yyvsp[0].val);}
#line 1711 "parse.c" /* yacc.c:1646  */
    break;

  case 29:
#line 134 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Fcall,(yyvsp[-3].val),(yyvsp[-1].val));}
#line 1717 "parse.c" /* yacc.c:1646  */
    break;

  case 30:
#line 135 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=(yyvsp[0].val);}
#line 1723 "parse.c" /* yacc.c:1646  */
    break;

  case 31:
#line 136 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=(yyvsp[0].val);}
#line 1729 "parse.c" /* yacc.c:1646  */
    break;

  case 32:
#line 137 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=(yyvsp[0].val);}
#line 1735 "parse.c" /* yacc.c:1646  */
    break;

  case 33:
#line 138 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=(yyvsp[0].val);}
#line 1741 "parse.c" /* yacc.c:1646  */
    break;

  case 34:
#line 139 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=(yyvsp[0].val);}
#line 1747 "parse.c" /* yacc.c:1646  */
    break;

  case 35:
#line 140 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Fassign,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1753 "parse.c" /* yacc.c:1646  */
    break;

  case 36:
#line 141 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Fassign,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1759 "parse.c" /* yacc.c:1646  */
    break;

  case 37:
#line 142 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPpp,(yyvsp[-1].val),-1);}
#line 1765 "parse.c" /* yacc.c:1646  */
    break;

  case 38:
#line 143 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPss,(yyvsp[-1].val),-1);}
#line 1771 "parse.c" /* yacc.c:1646  */
    break;

  case 39:
#line 144 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPme,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1777 "parse.c" /* yacc.c:1646  */
    break;

  case 40:
#line 145 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPde,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1783 "parse.c" /* yacc.c:1646  */
    break;

  case 41:
#line 146 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPdre,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1789 "parse.c" /* yacc.c:1646  */
    break;

  case 42:
#line 147 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPeuce,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1795 "parse.c" /* yacc.c:1646  */
    break;

  case 43:
#line 148 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPmode,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1801 "parse.c" /* yacc.c:1646  */
    break;

  case 44:
#line 149 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPsle,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1807 "parse.c" /* yacc.c:1646  */
    break;

  case 45:
#line 150 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPsre,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1813 "parse.c" /* yacc.c:1646  */
    break;

  case 46:
#line 151 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPpe,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1819 "parse.c" /* yacc.c:1646  */
    break;

  case 47:
#line 152 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPse,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1825 "parse.c" /* yacc.c:1646  */
    break;

  case 48:
#line 153 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPnb,(yyvsp[0].val),-1);}
#line 1831 "parse.c" /* yacc.c:1646  */
    break;

  case 49:
#line 154 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newcall("length",(yyvsp[0].val));}
#line 1837 "parse.c" /* yacc.c:1646  */
    break;

  case 50:
#line 155 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPor,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1843 "parse.c" /* yacc.c:1646  */
    break;

  case 51:
#line 156 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPand,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1849 "parse.c" /* yacc.c:1646  */
    break;

  case 52:
#line 157 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPand,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1855 "parse.c" /* yacc.c:1646  */
    break;

  case 53:
#line 158 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPid,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1861 "parse.c" /* yacc.c:1646  */
    break;

  case 54:
#line 159 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPeq,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1867 "parse.c" /* yacc.c:1646  */
    break;

  case 55:
#line 160 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPne,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1873 "parse.c" /* yacc.c:1646  */
    break;

  case 56:
#line 161 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPge,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1879 "parse.c" /* yacc.c:1646  */
    break;

  case 57:
#line 162 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPg,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1885 "parse.c" /* yacc.c:1646  */
    break;

  case 58:
#line 163 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPle,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1891 "parse.c" /* yacc.c:1646  */
    break;

  case 59:
#line 164 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPl,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1897 "parse.c" /* yacc.c:1646  */
    break;

  case 60:
#line 165 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPs,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1903 "parse.c" /* yacc.c:1646  */
    break;

  case 61:
#line 166 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPp,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1909 "parse.c" /* yacc.c:1646  */
    break;

  case 62:
#line 167 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPsl,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1915 "parse.c" /* yacc.c:1646  */
    break;

  case 63:
#line 168 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPsr,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1921 "parse.c" /* yacc.c:1646  */
    break;

  case 64:
#line 169 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPmod,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1927 "parse.c" /* yacc.c:1646  */
    break;

  case 65:
#line 170 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPdr,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1933 "parse.c" /* yacc.c:1646  */
    break;

  case 66:
#line 171 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPeuc,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1939 "parse.c" /* yacc.c:1646  */
    break;

  case 67:
#line 172 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPd,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1945 "parse.c" /* yacc.c:1646  */
    break;

  case 68:
#line 173 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPm,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1951 "parse.c" /* yacc.c:1646  */
    break;

  case 69:
#line 174 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPpl,(yyvsp[0].val),-1);}
#line 1957 "parse.c" /* yacc.c:1646  */
    break;

  case 70:
#line 175 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPn,(yyvsp[0].val),-1);}
#line 1963 "parse.c" /* yacc.c:1646  */
    break;

  case 71:
#line 176 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPpow,(yyvsp[-2].val),(yyvsp[0].val));}
#line 1969 "parse.c" /* yacc.c:1646  */
    break;

  case 72:
#line 177 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPtrans,(yyvsp[-1].val),-1);}
#line 1975 "parse.c" /* yacc.c:1646  */
    break;

  case 73:
#line 178 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPderiv,(yyvsp[-1].val),-1);}
#line 1981 "parse.c" /* yacc.c:1646  */
    break;

  case 74:
#line 179 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPfact,(yyvsp[-1].val),-1);}
#line 1987 "parse.c" /* yacc.c:1646  */
    break;

  case 75:
#line 180 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Fmatcoeff,(yyvsp[-1].val),(yyvsp[0].val));}
#line 1993 "parse.c" /* yacc.c:1646  */
    break;

  case 76:
#line 181 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=(yyvsp[0].val);}
#line 1999 "parse.c" /* yacc.c:1646  */
    break;

  case 77:
#line 182 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newtag((yyvsp[-2].val),(yyvsp[0].str).s,(yyvsp[0].str).c);}
#line 2005 "parse.c" /* yacc.c:1646  */
    break;

  case 78:
#line 183 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=(yyvsp[-1].val);}
#line 2011 "parse.c" /* yacc.c:1646  */
    break;

  case 79:
#line 186 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnodecom(Fentry,newentry((yyvsp[0].str).s),-1,(yyvsp[0].str).c);}
#line 2017 "parse.c" /* yacc.c:1646  */
    break;

  case 80:
#line 187 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Fmatcoeff,(yyvsp[-1].val),(yyvsp[0].val));}
#line 2023 "parse.c" /* yacc.c:1646  */
    break;

  case 81:
#line 188 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newtag((yyvsp[-2].val),(yyvsp[0].str).s,(yyvsp[0].str).c);}
#line 2029 "parse.c" /* yacc.c:1646  */
    break;

  case 82:
#line 191 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=(yyvsp[0].val);}
#line 2035 "parse.c" /* yacc.c:1646  */
    break;

  case 83:
#line 192 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Fmatrixelts,(yyvsp[-2].val),(yyvsp[0].val));}
#line 2041 "parse.c" /* yacc.c:1646  */
    break;

  case 84:
#line 195 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Fmatrixlines,(yyvsp[-2].val),(yyvsp[0].val));}
#line 2047 "parse.c" /* yacc.c:1646  */
    break;

  case 85:
#line 196 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Fmatrixlines,(yyvsp[-2].val),(yyvsp[0].val));}
#line 2053 "parse.c" /* yacc.c:1646  */
    break;

  case 86:
#line 199 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Fvec,-1,-1);}
#line 2059 "parse.c" /* yacc.c:1646  */
    break;

  case 87:
#line 200 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPrange,(yyvsp[-3].val),(yyvsp[-1].val));}
#line 2065 "parse.c" /* yacc.c:1646  */
    break;

  case 88:
#line 201 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Fmat,-1,-1);}
#line 2071 "parse.c" /* yacc.c:1646  */
    break;

  case 89:
#line 202 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Fvec,(yyvsp[-1].val),-1);}
#line 2077 "parse.c" /* yacc.c:1646  */
    break;

  case 90:
#line 203 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Fmat,(yyvsp[-1].val),-1);}
#line 2083 "parse.c" /* yacc.c:1646  */
    break;

  case 91:
#line 204 "parse.y" /* yacc.c:1646  */
    {YYABORT;}
#line 2089 "parse.c" /* yacc.c:1646  */
    break;

  case 92:
#line 207 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Flistarg,(yyvsp[0].val),(yyvsp[-3].val));}
#line 2095 "parse.c" /* yacc.c:1646  */
    break;

  case 93:
#line 210 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPcompr,(yyvsp[0].val),-2);}
#line 2101 "parse.c" /* yacc.c:1646  */
    break;

  case 94:
#line 211 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall3(OPcompr,(yyvsp[-2].val),-2,(yyvsp[0].val));}
#line 2107 "parse.c" /* yacc.c:1646  */
    break;

  case 95:
#line 212 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall(OPcomprc,(yyvsp[-2].val),(yyvsp[0].val));}
#line 2113 "parse.c" /* yacc.c:1646  */
    break;

  case 96:
#line 213 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newopcall3(OPcomprc,(yyvsp[-4].val),(yyvsp[0].val),(yyvsp[-2].val));}
#line 2119 "parse.c" /* yacc.c:1646  */
    break;

  case 97:
#line 216 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=addcurrexpr((yyvsp[-1].val),(yyvsp[-3].val));}
#line 2125 "parse.c" /* yacc.c:1646  */
    break;

  case 98:
#line 219 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=(yyvsp[0].val);}
#line 2131 "parse.c" /* yacc.c:1646  */
    break;

  case 99:
#line 220 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Fvararg,(yyvsp[-3].val),-1);}
#line 2137 "parse.c" /* yacc.c:1646  */
    break;

  case 100:
#line 221 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Frefarg,(yyvsp[0].val),-1);}
#line 2143 "parse.c" /* yacc.c:1646  */
    break;

  case 101:
#line 222 "parse.y" /* yacc.c:1646  */
    {if (!once) { yyerrok; s_errors.n--;} once=1;}
#line 2149 "parse.c" /* yacc.c:1646  */
    break;

  case 102:
#line 223 "parse.y" /* yacc.c:1646  */
    {once=0; (yyval.val)=newopcall(OPcat,(yyvsp[-3].val),(yyvsp[0].val));}
#line 2155 "parse.c" /* yacc.c:1646  */
    break;

  case 103:
#line 226 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=(yyvsp[0].val);}
#line 2161 "parse.c" /* yacc.c:1646  */
    break;

  case 104:
#line 227 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Flistarg,(yyvsp[-2].val),(yyvsp[0].val));}
#line 2167 "parse.c" /* yacc.c:1646  */
    break;

  case 105:
#line 230 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnodecom(Ffunction,newentry((yyvsp[-3].str).s),(yyvsp[-1].val),(yyvsp[-3].str).c);}
#line 2173 "parse.c" /* yacc.c:1646  */
    break;

  case 106:
#line 233 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnodecom(Ffunction,newmember((yyvsp[0].str).s),(yyvsp[-2].val),(yyvsp[0].str).c);}
#line 2179 "parse.c" /* yacc.c:1646  */
    break;

  case 107:
#line 237 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Fdeffunc,(yyvsp[-2].val),(yyvsp[0].val));}
#line 2185 "parse.c" /* yacc.c:1646  */
    break;

  case 108:
#line 239 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Fdeffunc,(yyvsp[-2].val),(yyvsp[0].val));}
#line 2191 "parse.c" /* yacc.c:1646  */
    break;

  case 109:
#line 240 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Flambda, (yyvsp[-2].val),(yyvsp[0].val));}
#line 2197 "parse.c" /* yacc.c:1646  */
    break;

  case 110:
#line 241 "parse.y" /* yacc.c:1646  */
    {(yyval.val)=newnode(Flambda, (yyvsp[-2].val),(yyvsp[0].val));}
#line 2203 "parse.c" /* yacc.c:1646  */
    break;


#line 2207 "parse.c" /* yacc.c:1646  */
      default: break;
    }
  /* User semantic actions sometimes alter yychar, and that requires
     that yytoken be updated with the new translation.  We take the
     approach of translating immediately before every use of yytoken.
     One alternative is translating here after every semantic action,
     but that translation would be missed if the semantic action invokes
     YYABORT, YYACCEPT, or YYERROR immediately after altering yychar or
     if it invokes YYBACKUP.  In the case of YYABORT or YYACCEPT, an
     incorrect destructor might then be invoked immediately.  In the
     case of YYERROR or YYBACKUP, subsequent parser actions might lead
     to an incorrect destructor call or verbose syntax error message
     before the lookahead is translated.  */
  YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);

  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);

  *++yyvsp = yyval;

  /* Now 'shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTOKENS];

  goto yynewstate;


/*--------------------------------------.
| yyerrlab -- here on detecting error.  |
`--------------------------------------*/
yyerrlab:
  /* Make sure we have latest lookahead translation.  See comments at
     user semantic actions for why this is necessary.  */
  yytoken = yychar == YYEMPTY ? YYEMPTY : YYTRANSLATE (yychar);

  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
#if ! YYERROR_VERBOSE
      yyerror (YY_("syntax error"));
#else
# define YYSYNTAX_ERROR yysyntax_error (&yymsg_alloc, &yymsg, \
                                        yyssp, yytoken)
      {
        char const *yymsgp = YY_("syntax error");
        int yysyntax_error_status;
        yysyntax_error_status = YYSYNTAX_ERROR;
        if (yysyntax_error_status == 0)
          yymsgp = yymsg;
        else if (yysyntax_error_status == 1)
          {
            if (yymsg != yymsgbuf)
              YYSTACK_FREE (yymsg);
            yymsg = (char *) YYSTACK_ALLOC (yymsg_alloc);
            if (!yymsg)
              {
                yymsg = yymsgbuf;
                yymsg_alloc = sizeof yymsgbuf;
                yysyntax_error_status = 2;
              }
            else
              {
                yysyntax_error_status = YYSYNTAX_ERROR;
                yymsgp = yymsg;
              }
          }
        yyerror (yymsgp);
        if (yysyntax_error_status == 2)
          goto yyexhaustedlab;
      }
# undef YYSYNTAX_ERROR
#endif
    }



  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
         error, discard it.  */

      if (yychar <= YYEOF)
        {
          /* Return failure if at end of input.  */
          if (yychar == YYEOF)
            YYABORT;
        }
      else
        {
          yydestruct ("Error: discarding",
                      yytoken, &yylval);
          yychar = YYEMPTY;
        }
    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*---------------------------------------------------.
| yyerrorlab -- error raised explicitly by YYERROR.  |
`---------------------------------------------------*/
yyerrorlab:

  /* Pacify compilers like GCC when the user code never invokes
     YYERROR and the label yyerrorlab therefore never appears in user
     code.  */
  if (/*CONSTCOND*/ 0)
     goto yyerrorlab;

  /* Do not reclaim the symbols of the rule whose action triggered
     this YYERROR.  */
  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);
  yystate = *yyssp;
  goto yyerrlab1;


/*-------------------------------------------------------------.
| yyerrlab1 -- common code for both syntax error and YYERROR.  |
`-------------------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;      /* Each real token shifted decrements this.  */

  for (;;)
    {
      yyn = yypact[yystate];
      if (!yypact_value_is_default (yyn))
        {
          yyn += YYTERROR;
          if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
            {
              yyn = yytable[yyn];
              if (0 < yyn)
                break;
            }
        }

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
        YYABORT;


      yydestruct ("Error: popping",
                  yystos[yystate], yyvsp);
      YYPOPSTACK (1);
      yystate = *yyssp;
      YY_STACK_PRINT (yyss, yyssp);
    }

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END


  /* Shift the error token.  */
  YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);

  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturn;

/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturn;

#if !defined yyoverflow || YYERROR_VERBOSE
/*-------------------------------------------------.
| yyexhaustedlab -- memory exhaustion comes here.  |
`-------------------------------------------------*/
yyexhaustedlab:
  yyerror (YY_("memory exhausted"));
  yyresult = 2;
  /* Fall through.  */
#endif

yyreturn:
  if (yychar != YYEMPTY)
    {
      /* Make sure we have latest lookahead translation.  See comments at
         user semantic actions for why this is necessary.  */
      yytoken = YYTRANSLATE (yychar);
      yydestruct ("Cleanup: discarding lookahead",
                  yytoken, &yylval);
    }
  /* Do not reclaim the symbols of the rule whose action triggered
     this YYABORT or YYACCEPT.  */
  YYPOPSTACK (yylen);
  YY_STACK_PRINT (yyss, yyssp);
  while (yyssp != yyss)
    {
      yydestruct ("Cleanup: popping",
                  yystos[*yyssp], yyvsp);
      YYPOPSTACK (1);
    }
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
#if YYERROR_VERBOSE
  if (yymsg != yymsgbuf)
    YYSTACK_FREE (yymsg);
#endif
  return yyresult;
}
#line 244 "parse.y" /* yacc.c:1906  */

int yyerror(const char *s)
{
  int n=stack_new(&s_errors);
  errors[n].lineno=linecount;
  errors[n].txt=strdup(s);
  if (yydebug) fprintf(stderr,"%s:%d: %s\n",nameparse,linecount,s);
  return 0;
}
